cmd

package
v0.0.0-...-ca8e484 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 26, 2026 License: Apache-2.0 Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute() int

Execute is called by the main method of the package

Types

type PluginConfig

type PluginConfig struct {
	SecurityModulePlugin string `json:"securityModule"`
}

PluginConfig is the JSON configuration for loading plugins

type ServerConfig

type ServerConfig struct {
	KafkaBridges map[string]*kafka.KafkaBridgeConf `json:"kafka"`
	Webhooks     map[string]*rest.RESTGatewayConf  `json:"webhooks"`
	RESTGateways map[string]*rest.RESTGatewayConf  `json:"rest"`
	Plugins      PluginConfig                      `json:"plugins"`
}

ServerConfig is the parent YAML structure that configures ethconnect to run with a set of individual commands as goroutines (rather than the simple commandline mode that runs a single command)

Jump to